import os
from avocado import Test


class VmimageTest(Test):
    """
    Test demonstrating VM image dependency usage.
    The vmimage dependency runner will ensure the required VM image
    is downloaded and cached before the test execution begins.

    :avocado: dependency={"type": "vmimage", "provider": "fedora", "version": "41", "arch": "s390x"}
    """

    def test_vmimage_exists(self):
        """
        Verify that the VM image was downloaded by the vmimage runner.
        """
        from avocado.core.settings import settings

        # Get cache directory from settings
        cache_dir = settings.as_dict().get("datadir.paths.cache_dirs")[0]
        cache_base = os.path.join(cache_dir, "by_location")

        # The image should be in the cache since the runner downloaded it
        self.assertTrue(
            os.path.exists(cache_base),
            f"Cache directory {cache_base} does not exist"
        )

        # Log cache contents for debugging
        self.log.info("Cache directory contents:")
        for root, _, files in os.walk(cache_base):
            for f in files:
                if f.endswith((".qcow2", ".raw")):
                    self.log.info("Found image: %s", os.path.join(root, f))


class MultiArchVmimageTest(Test):
    """
    Test demonstrating multiple VM image dependencies with different architectures.

    :avocado: dependency={"type": "vmimage", "provider": "fedora", "version": "41", "arch": "s390x"}
    :avocado: dependency={"type": "vmimage", "provider": "fedora", "version": "41", "arch": "x86_64"}
    """

    def test_multiple_images(self):
        """
        Verify that multiple VM images can be handled by the runner.
        """
        self.log.info("Test with multiple VM image dependencies")


class UbuntuVmimageTest(Test):
    """
    Test demonstrating VM image dependency with a different provider.

    :avocado: dependency={"type": "vmimage", "provider": "ubuntu", "version": "22.04", "arch": "x86_64"}
    """

    def test_ubuntu_image(self):
        """
        Verify that Ubuntu images can be handled by the runner.
        """
        self.log.info("Test with Ubuntu VM image dependency")


# Testing instructions:
#
# 1. Clear the cache first:
#    $ avocado cache clear
#
# 2. Run the tests:
#    $ avocado run examples/tests/dependency_vmimage.py
#
# 3. Check the cache to see downloaded images:
#    $ avocado cache list
#
# 4. Run again to verify cache is used:
#    $ avocado run examples/tests/dependency_vmimage.py
#
# The vmimage runner should:
# - Download the required images on first run
# - Use cached images on subsequent runs
# - Handle multiple dependencies per test
# - Support different providers and architectures
